pub enum CryptoError {
InvalidSignature,
InvalidKey,
ChaCha20Poly1305EncryptionError(Error),
IncongruentLength(usize, usize),
NonceExhausted,
InvalidSession,
TryFromSliceError(TryFromSliceError),
}Variants
InvalidSignature
InvalidKey
Key bytes failed to decode, or a public key does not belong to its secret key
ChaCha20Poly1305EncryptionError(Error)
IncongruentLength(usize, usize)
NonceExhausted
The session’s message counter is used up; start a new session
InvalidSession
Serialized session has an unknown version or a malformed field
TryFromSliceError(TryFromSliceError)